@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,14 +18,13 @@ from typing import (
     AsyncIterator,
     Awaitable,
     Callable,
+    Iterator,
+    Optional,
     Sequence,
     Tuple,
-    Optional,
-    Iterator,
 )
 
-from google.cloud.bigquery_datatransfer_v1.types import datatransfer
-from google.cloud.bigquery_datatransfer_v1.types import transfer
+from google.cloud.bigquery_datatransfer_v1.types import datatransfer, transfer
 
 
 class ListDataSourcesPager:
