@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ from typing import Dict, Type
 from .base import DataTransferServiceTransport
 from .grpc import DataTransferServiceGrpcTransport
 from .grpc_asyncio import DataTransferServiceGrpcAsyncIOTransport
-
+from .rest import DataTransferServiceRestInterceptor, DataTransferServiceRestTransport
 
 # Compile a registry of transports.
 _transport_registry = (
@@ -27,9 +27,12 @@ _transport_registry = (
 )  # type: Dict[str, Type[DataTransferServiceTransport]]
 _transport_registry["grpc"] = DataTransferServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = DataTransferServiceGrpcAsyncIOTransport
+_transport_registry["rest"] = DataTransferServiceRestTransport
 
 __all__ = (
     "DataTransferServiceTransport",
     "DataTransferServiceGrpcTransport",
     "DataTransferServiceGrpcAsyncIOTransport",
+    "DataTransferServiceRestTransport",
+    "DataTransferServiceRestInterceptor",
 )
