@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,21 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers_async
+from google.api_core import gapic_v1, grpc_helpers_async
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.cloud.location import locations_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
-from google.cloud.bigquery_datatransfer_v1.types import datatransfer
-from google.cloud.bigquery_datatransfer_v1.types import transfer
-from google.protobuf import empty_pb2  # type: ignore
-from .base import DataTransferServiceTransport, DEFAULT_CLIENT_INFO
+from google.cloud.bigquery_datatransfer_v1.types import datatransfer, transfer
+
+from .base import DEFAULT_CLIENT_INFO, DataTransferServiceTransport
 from .grpc import DataTransferServiceGrpcTransport
 
 
@@ -52,7 +51,7 @@ class DataTransferServiceGrpcAsyncIOTransport(DataTransferServiceTransport):
     def create_channel(
         cls,
         host: str = "bigquerydatatransfer.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -95,23 +94,24 @@ class DataTransferServiceGrpcAsyncIOTransport(DataTransferServiceTransport):
         self,
         *,
         host: str = "bigquerydatatransfer.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
-        channel: aio.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
-        quota_project_id=None,
+        channel: Optional[aio.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
         Args:
             host (Optional[str]):
-                 The hostname to connect to.
+                 The hostname to connect to (default: 'bigquerydatatransfer.googleapis.com').
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -201,6 +201,7 @@ class DataTransferServiceGrpcAsyncIOTransport(DataTransferServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -651,14 +652,15 @@ class DataTransferServiceGrpcAsyncIOTransport(DataTransferServiceTransport):
     ) -> Callable[[datatransfer.EnrollDataSourcesRequest], Awaitable[empty_pb2.Empty]]:
         r"""Return a callable for the enroll data sources method over gRPC.
 
-        Enroll data sources in a user project. This allows
-        users to create transfer configurations for these data
-        sources. They will also appear in the ListDataSources
-        RPC and as such, will appear in the BigQuery UI
-        'https://bigquery.cloud.google.com' (and the documents
-        can be found at
-        https://cloud.google.com/bigquery/bigquery-web-ui and
-        https://cloud.google.com/bigquery/docs/working-with-transfers).
+        Enroll data sources in a user project. This allows users to
+        create transfer configurations for these data sources. They will
+        also appear in the ListDataSources RPC and as such, will appear
+        in the `BigQuery
+        UI <https://console.cloud.google.com/bigquery>`__, and the
+        documents can be found in the public guide for `BigQuery Web
+        UI <https://cloud.google.com/bigquery/bigquery-web-ui>`__ and
+        `Data Transfer
+        Service <https://cloud.google.com/bigquery/docs/working-with-transfers>`__.
 
         Returns:
             Callable[[~.EnrollDataSourcesRequest],
@@ -681,5 +683,41 @@ class DataTransferServiceGrpcAsyncIOTransport(DataTransferServiceTransport):
     def close(self):
         return self.grpc_channel.close()
 
+    @property
+    def list_locations(
+        self,
+    ) -> Callable[
+        [locations_pb2.ListLocationsRequest], locations_pb2.ListLocationsResponse
+    ]:
+        r"""Return a callable for the list locations method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_locations" not in self._stubs:
+            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
+                "/google.cloud.location.Locations/ListLocations",
+                request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
+                response_deserializer=locations_pb2.ListLocationsResponse.FromString,
+            )
+        return self._stubs["list_locations"]
+
+    @property
+    def get_location(
+        self,
+    ) -> Callable[[locations_pb2.GetLocationRequest], locations_pb2.Location]:
+        r"""Return a callable for the list locations method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_location" not in self._stubs:
+            self._stubs["get_location"] = self.grpc_channel.unary_unary(
+                "/google.cloud.location.Locations/GetLocation",
+                request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
+                response_deserializer=locations_pb2.Location.FromString,
+            )
+        return self._stubs["get_location"]
+
 
 __all__ = ("DataTransferServiceGrpcAsyncIOTransport",)
