@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,12 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from __future__ import annotations
+
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
+from google.protobuf import wrappers_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.bigquery.datatransfer.v1",
@@ -29,6 +32,7 @@ __protobuf__ = proto.module(
         "ScheduleOptions",
         "UserInfo",
         "TransferConfig",
+        "EncryptionConfiguration",
         "TransferRun",
         "TransferMessage",
     },
@@ -36,7 +40,18 @@ __protobuf__ = proto.module(
 
 
 class TransferType(proto.Enum):
-    r"""DEPRECATED. Represents data transfer type."""
+    r"""DEPRECATED. Represents data transfer type.
+
+    Values:
+        TRANSFER_TYPE_UNSPECIFIED (0):
+            Invalid or Unknown transfer type placeholder.
+        BATCH (1):
+            Batch data transfer.
+        STREAMING (2):
+            Streaming data transfer. Streaming data
+            source currently doesn't support multiple
+            transfer configs per project.
+    """
     _pb_options = {"deprecated": True}
     TRANSFER_TYPE_UNSPECIFIED = 0
     BATCH = 1
@@ -44,7 +59,23 @@ class TransferType(proto.Enum):
 
 
 class TransferState(proto.Enum):
-    r"""Represents data transfer run state."""
+    r"""Represents data transfer run state.
+
+    Values:
+        TRANSFER_STATE_UNSPECIFIED (0):
+            State placeholder (0).
+        PENDING (2):
+            Data transfer is scheduled and is waiting to
+            be picked up by data transfer backend (2).
+        RUNNING (3):
+            Data transfer is in progress (3).
+        SUCCEEDED (4):
+            Data transfer completed successfully (4).
+        FAILED (5):
+            Data transfer failed (5).
+        CANCELLED (6):
+            Data transfer is cancelled (6).
+    """
     TRANSFER_STATE_UNSPECIFIED = 0
     PENDING = 2
     RUNNING = 3
@@ -63,7 +94,10 @@ class EmailPreferences(proto.Message):
             transfer run failures.
     """
 
-    enable_failure_email = proto.Field(proto.BOOL, number=1,)
+    enable_failure_email: bool = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
 
 
 class ScheduleOptions(proto.Message):
@@ -94,14 +128,27 @@ class ScheduleOptions(proto.Message):
             option.
     """
 
-    disable_auto_scheduling = proto.Field(proto.BOOL, number=3,)
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    disable_auto_scheduling: bool = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
+    start_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class UserInfo(proto.Message):
     r"""Information about a user.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         email (str):
             E-mail address of the user.
@@ -109,7 +156,11 @@ class UserInfo(proto.Message):
             This field is a member of `oneof`_ ``_email``.
     """
 
-    email = proto.Field(proto.STRING, number=1, optional=True,)
+    email: str = proto.Field(
+        proto.STRING,
+        number=1,
+        optional=True,
+    )
 
 
 class TransferConfig(proto.Message):
@@ -126,9 +177,10 @@ class TransferConfig(proto.Message):
     Attributes:
         name (str):
             The resource name of the transfer config. Transfer config
-            names have the form
-            ``projects/{project_id}/locations/{region}/transferConfigs/{config_id}``.
-            Where ``config_id`` is usually a uuid, even though it is not
+            names have the form either
+            ``projects/{project_id}/locations/{region}/transferConfigs/{config_id}``
+            or ``projects/{project_id}/transferConfigs/{config_id}``,
+            where ``config_id`` is usually a UUID, even though it is not
             guaranteed or required. The name is ignored when creating a
             transfer config.
         destination_dataset_id (str):
@@ -139,14 +191,19 @@ class TransferConfig(proto.Message):
             User specified display name for the data
             transfer.
         data_source_id (str):
-            Data source id. Cannot be changed once data
-            transfer is created.
+            Data source ID. This cannot be changed once
+            data transfer is created. The full list of
+            available data source IDs can be returned
+            through an API call:
+
+            https://cloud.google.com/bigquery-transfer/docs/reference/datatransfer/rest/v1/projects.locations.dataSources/list
         params (google.protobuf.struct_pb2.Struct):
             Parameters specific to each data source. For
             more information see the bq tab in the 'Setting
             up a data transfer' section for each data
             source. For example the parameters for Cloud
             Storage transfers are listed here:
+
             https://cloud.google.com/bigquery-transfer/docs/cloud-storage-transfer#bq
         schedule (str):
             Data transfer schedule. If the data source does not support
@@ -208,30 +265,114 @@ class TransferConfig(proto.Message):
             populated.
 
             This field is a member of `oneof`_ ``_owner_info``.
+        encryption_configuration (google.cloud.bigquery_datatransfer_v1.types.EncryptionConfiguration):
+            The encryption configuration part. Currently,
+            it is only used for the optional KMS key name.
+            The BigQuery service account of your project
+            must be granted permissions to use the key. Read
+            methods will return the key name applied in
+            effect. Write methods will apply the key if it
+            is present, or otherwise try to apply project
+            default keys if it is absent.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    destination_dataset_id = proto.Field(proto.STRING, number=2, oneof="destination",)
-    display_name = proto.Field(proto.STRING, number=3,)
-    data_source_id = proto.Field(proto.STRING, number=5,)
-    params = proto.Field(proto.MESSAGE, number=9, message=struct_pb2.Struct,)
-    schedule = proto.Field(proto.STRING, number=7,)
-    schedule_options = proto.Field(proto.MESSAGE, number=24, message="ScheduleOptions",)
-    data_refresh_window_days = proto.Field(proto.INT32, number=12,)
-    disabled = proto.Field(proto.BOOL, number=13,)
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    next_run_time = proto.Field(
-        proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    state = proto.Field(proto.ENUM, number=10, enum="TransferState",)
-    user_id = proto.Field(proto.INT64, number=11,)
-    dataset_region = proto.Field(proto.STRING, number=14,)
-    notification_pubsub_topic = proto.Field(proto.STRING, number=15,)
-    email_preferences = proto.Field(
-        proto.MESSAGE, number=18, message="EmailPreferences",
+    destination_dataset_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="destination",
     )
-    owner_info = proto.Field(
-        proto.MESSAGE, number=27, optional=True, message="UserInfo",
+    display_name: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    data_source_id: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    params: struct_pb2.Struct = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message=struct_pb2.Struct,
+    )
+    schedule: str = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    schedule_options: "ScheduleOptions" = proto.Field(
+        proto.MESSAGE,
+        number=24,
+        message="ScheduleOptions",
+    )
+    data_refresh_window_days: int = proto.Field(
+        proto.INT32,
+        number=12,
+    )
+    disabled: bool = proto.Field(
+        proto.BOOL,
+        number=13,
+    )
+    update_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    next_run_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
+    )
+    state: "TransferState" = proto.Field(
+        proto.ENUM,
+        number=10,
+        enum="TransferState",
+    )
+    user_id: int = proto.Field(
+        proto.INT64,
+        number=11,
+    )
+    dataset_region: str = proto.Field(
+        proto.STRING,
+        number=14,
+    )
+    notification_pubsub_topic: str = proto.Field(
+        proto.STRING,
+        number=15,
+    )
+    email_preferences: "EmailPreferences" = proto.Field(
+        proto.MESSAGE,
+        number=18,
+        message="EmailPreferences",
+    )
+    owner_info: "UserInfo" = proto.Field(
+        proto.MESSAGE,
+        number=27,
+        optional=True,
+        message="UserInfo",
+    )
+    encryption_configuration: "EncryptionConfiguration" = proto.Field(
+        proto.MESSAGE,
+        number=28,
+        message="EncryptionConfiguration",
+    )
+
+
+class EncryptionConfiguration(proto.Message):
+    r"""Represents the encryption configuration for a transfer.
+
+    Attributes:
+        kms_key_name (google.protobuf.wrappers_pb2.StringValue):
+            The name of the KMS key used for encrypting
+            BigQuery data.
+    """
+
+    kms_key_name: wrappers_pb2.StringValue = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=wrappers_pb2.StringValue,
     )
 
 
@@ -270,6 +411,7 @@ class TransferRun(proto.Message):
             the 'Setting up a data transfer' section for
             each data source. For example the parameters for
             Cloud Storage transfers are listed here:
+
             https://cloud.google.com/bigquery-transfer/docs/cloud-storage-transfer#bq
         destination_dataset_id (str):
             Output only. The BigQuery target dataset id.
@@ -303,24 +445,75 @@ class TransferRun(proto.Message):
             this run was derived from.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    schedule_time = proto.Field(
-        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    run_time = proto.Field(proto.MESSAGE, number=10, message=timestamp_pb2.Timestamp,)
-    error_status = proto.Field(proto.MESSAGE, number=21, message=status_pb2.Status,)
-    start_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
-    params = proto.Field(proto.MESSAGE, number=9, message=struct_pb2.Struct,)
-    destination_dataset_id = proto.Field(proto.STRING, number=2, oneof="destination",)
-    data_source_id = proto.Field(proto.STRING, number=7,)
-    state = proto.Field(proto.ENUM, number=8, enum="TransferState",)
-    user_id = proto.Field(proto.INT64, number=11,)
-    schedule = proto.Field(proto.STRING, number=12,)
-    notification_pubsub_topic = proto.Field(proto.STRING, number=23,)
-    email_preferences = proto.Field(
-        proto.MESSAGE, number=25, message="EmailPreferences",
+    schedule_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    run_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message=timestamp_pb2.Timestamp,
+    )
+    error_status: status_pb2.Status = proto.Field(
+        proto.MESSAGE,
+        number=21,
+        message=status_pb2.Status,
+    )
+    start_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
+    params: struct_pb2.Struct = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message=struct_pb2.Struct,
+    )
+    destination_dataset_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="destination",
+    )
+    data_source_id: str = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    state: "TransferState" = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum="TransferState",
+    )
+    user_id: int = proto.Field(
+        proto.INT64,
+        number=11,
+    )
+    schedule: str = proto.Field(
+        proto.STRING,
+        number=12,
+    )
+    notification_pubsub_topic: str = proto.Field(
+        proto.STRING,
+        number=23,
+    )
+    email_preferences: "EmailPreferences" = proto.Field(
+        proto.MESSAGE,
+        number=25,
+        message="EmailPreferences",
     )
 
 
@@ -338,17 +531,37 @@ class TransferMessage(proto.Message):
     """
 
     class MessageSeverity(proto.Enum):
-        r"""Represents data transfer user facing message severity."""
+        r"""Represents data transfer user facing message severity.
+
+        Values:
+            MESSAGE_SEVERITY_UNSPECIFIED (0):
+                No severity specified.
+            INFO (1):
+                Informational message.
+            WARNING (2):
+                Warning message.
+            ERROR (3):
+                Error message.
+        """
         MESSAGE_SEVERITY_UNSPECIFIED = 0
         INFO = 1
         WARNING = 2
         ERROR = 3
 
-    message_time = proto.Field(
-        proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
+    message_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    severity: MessageSeverity = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=MessageSeverity,
+    )
+    message_text: str = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    severity = proto.Field(proto.ENUM, number=2, enum=MessageSeverity,)
-    message_text = proto.Field(proto.STRING, number=3,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
